# -*- coding: utf-8 -*-
from baseapi import BaseApi


class Student(BaseApi):
    dataservername = 'EduAlunoData'
    def create(self, **kwargs):
        return super(Student, self).create({
            'NewDataSet': {
                'SAluno': {
                    'CODCOLIGADA': kwargs.get('codcoligada'),
                    'CODTIPOCURSO': kwargs.get('codtipocurso'),
                    'DTNASCIMENTO': '{:%Y-%m-%d}T03:00:00.000'.format(kwargs.get('data_nascimento')),
                    'ESTADONATAL': kwargs.get('estado_natal'),
                    'NATURALIDADE': kwargs.get('naturalidade'),
                    'NOME': kwargs.get('nome'),
                    'RA': kwargs.get('ra'),
                }
            }
        }, 'CODCOLIGADA={}'.format(kwargs.get('codcoligada')))



# -*- coding: utf-8 -*-
from zeep import Client
from zeep.transports import Transport
from requests import Session
from requests.auth import HTTPBasicAuth

def create_service(server, username, password):
    session = Session()
    session.auth = HTTPBasicAuth(username,password)
    client = Client(wsdl='http://{}/wsDataServer/MEX?wsdl'.format(server), transport=Transport(session=session))
    return client.create_service('{http://www.totvs.com/}RM_IwsDataServer', 'http://{}/wsDataServer/IwsDataServer'.format(server))



# -*- coding: utf-8 -*-
from datetime import datetime
from baseapi import BaseApi


class Client(BaseApi):
    dataservername = 'FinCFODataBR'
    def create(self,**kwargs):
        return super(Client, self).create({
            'NewDataSet': {
                'FCFO': {
                    'ATIVO': kwargs.get('ativo'),
                    'CODCFO': -1,
                    'IDCFO': -1,
                    'CODEXTERNO': kwargs.get('codexterno'),
                    'CODCOLIGADA': kwargs.get('codcoligada'),
                    'CODCOLTCF': kwargs.get('codcoligada'),
                    'CGCCFO': kwargs.get('cpf_cnpj'),
                    'TIPORUA': kwargs.get('tipo_rua'),
                    'TIPOBAIRRO': kwargs.get('tipo_bairro'),
                    'BAIRRO': kwargs.get('bairro'),
                    'RUA': kwargs.get('rua'),
                    'NUMERO': kwargs.get('numero'),
                    'CEP': kwargs.get('cep'),
                    'CODETD': kwargs.get('estado'),
                    'CIDADE': kwargs.get('cidade'),
                    'CODMUNICIPIO': kwargs.get('codigo_municipio'),
                    'PAIS': kwargs.get('cod_pais'),
                    'DTNASCIMENTO': '{:%Y-%m-%d}T03:00:00.000'.format(kwargs.get('data_nascimento')),
                    'NOME': kwargs.get('nome'),
                    'NOMEFANTASIA': kwargs.get('nome'),
                    'PAGREC': kwargs.get('classificacao'),
                    'PESSOAFISOUJUR': kwargs.get('categoria'),
                    'CODTCF': kwargs.get('tipo_cliente'),
                }
            }
        }, 'CODCOLIGADA={}'.format(kwargs.get('codcoligada_contexto')))


class Billet(BaseApi):
    dataservername = 'FinLanBoletoData'
    def create(self,**kwargs):
        return super(Billet, self).create({
            'FinLAN': {
                'FLAN': {
                    'CODCOLIGADA': kwargs.get('codcoligada'),
                    'IDLAN': -1,
                    'PAGREC': kwargs.get('classificacao'),
                    'CODTDO': kwargs.get('tipo_documento'),
                    'DATAVENCIMENTO': kwargs.get('data_vencimento'),
                    'DATAEMISSAO': "{:%d/%m/%Y %H:%M:%S}".format(datetime.now()),
                    'VALORORIGINAL': kwargs.get('valor'),
                    'CODCOLCFO': kwargs.get('codcoligada_cfo'),
                    'CODCFO': kwargs.get('codcliente'),
                    'CODFILIAL': kwargs.get('codfilial'),
                    'SERIEDOCUMENTO': '@@@',
                    'CODCXA': kwargs.get('conta'),
                    'CODMOEVALORORIGINAL': 'R$',
                    'HISTORICO': kwargs.get('historico'),
                    'CODCCUSTO': kwargs.get('centro_custo'),
                },
            }
        }, 'CODCOLIGADA={}'.format(kwargs.get('codcoligada_contexto')))



# -*- coding: utf-8 -*-
from auth import create_service
from dicttoxml import dicttoxml
from lxml import objectify


class BaseApi(object):
    dataservername = ''

    def __init__(self, server, username, password):
        self.service = create_service(server, username, password)

    def create(self, dict, context):
        xml = dicttoxml(dict, attr_type=False)
        return self.service.SaveRecord(DataServerName=self.dataservername, XML=xml, Contexto=context)

    def get(self, codcoligada, id):
        primary_key = '{};{}'.format(codcoligada, id)
        return_from_api = self.service.ReadRecord(
            DataServerName=self.dataservername, PrimaryKey=primary_key, Contexto='CODCOLIGADA={}'.format(codcoligada))
        return objectify.fromstring(return_from_api)



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='totvserprm',
    version='1.3',
    description='API para webservices do TOTVS ERP RM',
    url='https://github.com/grupoandrademartins/totvserprm',
    author='Rafael G. Winter, Túlio Cesar Martins',
    author_email='totvs-erp-rm-python@googlegroups.com',
    license='MIT',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    install_requires=[
      'dicttoxml',
      'lxml',
      'requests',
      'zeep'
    ],
    keywords='totvs webservice erp rm soap api',
    long_description=long_description
)
